require 'uu/os/rest/dto'
require 'uu/os/uesuri'


# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Activity Action.
    module ActivityAction
      # @see ActivityAction#get_attributes
      class ActivityActionAttributes < UU::OS::REST::DTO

        # Code of the activity action. Never nil.
        attr_accessor :code

        # URI of the activity action. Never nil.
        attr_accessor :uri

        # URI of the entity (activity template or activity instance) this activity action
        # is created for. Never nil.
        attr_accessor :entity_uri

        # Type of the activity action. Never nil.
        # 
        # @see UU::OS::Activity::ActivityStateType
        attr_accessor :type

        # URI of an activity state template. When entity_uri is set into the state
        # represented by this state template, the activity action will be executed. This parameter
        # is never nil.
        attr_accessor :activity_state_template_uri

        # URI of the artifact state template that will be set to an artifact created according
        # to the related meta artifact after this activity action is executed. This parameter
        # is filled only if the type is SET_ARTIFACT_STATE_ACTION.
        attr_accessor :target_artifact_state_template_uri

        # URI of the activity state template that will be set to its related activity template
        # after this activity action is executed. This parameter is filled only if the type
        # is SET_ACTIVITY_STATE_ACTION.
        attr_accessor :target_activity_state_template_uri

        # URI of the artifact that represents a macro that will be run after this activity
        # action is executed. This parameter is filled only if the type is EXEC_MACRO_ACTION.
        attr_accessor :macro_uri

        # Creation time of the activity action.
        attr_accessor :creation_time

        # Modification time of the activity action.
        attr_accessor :modification_time

        # Version of the activity action.
        attr_accessor :version

        # URI of the entity type of the activity action. Never nil.
        attr_accessor :entity_type_uri

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def entity_uri
          attributes[:entityUri]
        end

        def entity_uri=(val)
          if val
            attributes[:entityUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityUri] = nil
          end
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def activity_state_template_uri
          attributes[:activityStateTemplateUri]
        end

        def activity_state_template_uri=(val)
          if val
            attributes[:activityStateTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:activityStateTemplateUri] = nil
          end
        end

        def target_artifact_state_template_uri
          attributes[:targetArtifactStateTemplateUri]
        end

        def target_artifact_state_template_uri=(val)
          if val
            attributes[:targetArtifactStateTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:targetArtifactStateTemplateUri] = nil
          end
        end

        def target_activity_state_template_uri
          attributes[:targetActivityStateTemplateUri]
        end

        def target_activity_state_template_uri=(val)
          if val
            attributes[:targetActivityStateTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:targetActivityStateTemplateUri] = nil
          end
        end

        def macro_uri
          attributes[:macroUri]
        end

        def macro_uri=(val)
          if val
            attributes[:macroUri] = UU::OS::UESURI.new(val)
          else
            attributes[:macroUri] = nil
          end
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end

  end
end
