require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Basic group.
    module BasicGroup
      class BasicGroupAttributes < UU::OS::REST::DTO

        # Specifies the type of basic group. There can be only one basic group for each of the AUTHORITIES, AUDITORS, EXECUTIVES and READERS types in the organizational unit of newly created basic group. If nil or empty the create command fails. Selected basic group type cannot be changed after the basic group creation.
        attr_accessor :basic_group_type

        # Code of the basic group. Never nil.
        attr_accessor :code

        # Normalized UESURI of the organizational unit where the basic group is located. Never nil.
        # @deprecated
        attr_accessor :company_uri

        # Normalized UESURI of the competent role. Never nil.
        attr_accessor :competent_role_uri

        # Creation stamp of the basic group.
        attr_accessor :creation_stamp

        # Creation time of the basic group.
        attr_accessor :creation_time

        # Description of the basic group.
        attr_accessor :description

        # UESURI of the entity type of the basic group. Never nil.
        attr_accessor :entity_type_uri

        # URI of the basic group's icon. If nil is set, the basic group uses icon from meta artifact.
        attr_accessor :icon_uri

        # Normalized UESURI of the container where the basic group is located. Never nil.
        attr_accessor :location_uri

        # Normalized UESURI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # Modification stamp of the basic group.
        attr_accessor :modification_stamp

        # Modification time of the basic group.
        attr_accessor :modification_time

        # Name of the basic group. Never nil.
        attr_accessor :name

        # Normalized UESURI of the organizational unit where the basic group is located. Never nil.
        attr_accessor :organizational_unit_uri

        # Specifies if it is possible to search the basic group in its territory. Never nil.
        attr_accessor :searchable_in_territory

        # Security level of the basic group. Never nil.
        attr_accessor :security_level

        # Normalized UESURI of the basic group. Never nil.
        attr_accessor :uri

        # Version of the basic group.
        attr_accessor :version
        
        attr_accessor :component_content
        
        def basic_group_type
          attributes[:basicGroupType]
        end

        def basic_group_type=(val)
          attributes[:basicGroupType] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def searchable_in_territory
          attributes[:searchableInTerritory]
        end

        def searchable_in_territory=(val)
          attributes[:searchableInTerritory] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end
        
        def component_content
          attributes[:componentContent]
        end

        def component_content=(val)
          attributes[:componentContent] = val
        end
        
      end
    end
  end
end