require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS

    module Cast
      class CastAttributes < UU::OS::REST::DTO

        # UESURI of the subject (role or group) to which the {#casted_subject_uri casted_subject_uri} is casted.
        # Never nil.
        attr_accessor :subject_uri

        # UESURI of the subject (role or group) which is casted to the {#subject_uri subject_uri}. Never nil.
        attr_accessor :casted_subject_uri

        # The level of the cast relation. Never nil.
        #
        # @see UU::OS::Cast::CastLevel
        attr_accessor :level

        # Specifies whether the cast is the primary cast to the role. Applicable only if
        # the {#subject_uri subject_uri} (main entity) is a role. Only a {#visible visible} cast in
        # {UU::OS::Cast::CastState::ACTIVE ACTIVE} {#state state} and
        # {UU::OS::Cast::CastLevel::EXECUTIVE EXECUTIVE} {#level level} can become primary. Never nil.
        attr_accessor :primary

        # Creation time of the cast. Never nil.
        attr_accessor :date_from

        # The date when the cast will be automatically set to the {UU::OS::Cast::CastState::PASSIVE PASSIVE} state. 
        # If the subject is a Role and the cast is the {UU::OS::Cast::CastCreate#primary primary} cast to the Role, 
        # then there must be either another {UU::OS::Cast::CastState::ACTIVE ACTIVE} visible cast with {UU::OS::Cast::CastLevel::EXECUTIVE EXECUTIVE} 
        # {#level level} to the Role which will become the primary cast, or no cast at all; otherwise the cast state will not be changed.

        attr_accessor :date_to

        # Deprecated. In territories with cast strategies of 2 or higher, all casts are either ACTIVE or they do not exist at all.
        # In territories with a cast strategy of 1 or lower, PASSIVE casts are just ignored while only ACTIVE casts are used in cast calculations.
        # @deprecated
        attr_accessor :state

        # Name of the subject (role or group) to which the {#casted_subject_uri casted_subject_uri} is casted. Never
        # nil.
        attr_accessor :subject_name

        # Code of the subject (role or group) to which the {#casted_subject_uri casted_subject_uri} is casted. Never
        # nil.
        attr_accessor :subject_code

        # Entity type URI of subject. Never nil.
        attr_accessor :subject_entity_type_uri

        # Name of the subject (role or group) which is casted to the {#subject_uri subject_uri}. Never nil.
        attr_accessor :casted_subject_name

        # Code of the subject (role or group) which is casted to the {#subject_uri subject_uri}. Never nil.
        attr_accessor :casted_subject_code

        # Entity type URI of casted subject. Never nil.
        attr_accessor :casted_subject_entity_type_uri

        # Specifies direction of the cast.
        #
        # @see UU::OS::Cast::CastDirection
        attr_accessor :cast_direction

        # Specifies whether the cast is visible in Show Casts use case. Never nil.
        attr_accessor :visible

        def subject_uri
          attributes[:subjectUri]
        end

        def subject_uri=(val)
          if val
            attributes[:subjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:subjectUri] = nil
          end
        end

        def casted_subject_uri
          attributes[:castedSubjectUri]
        end

        def casted_subject_uri=(val)
          if val
            attributes[:castedSubjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectUri] = nil
          end
        end

        def level
          attributes[:level]
        end

        def level=(val)
          attributes[:level] = val
        end

        def primary
          attributes[:primary]
        end

        def primary=(val)
          attributes[:primary] = val
        end

        def date_from
          attributes[:dateFrom]
        end

        def date_from=(val)
          attributes[:dateFrom] = val
        end

        def date_to
          attributes[:dateTo]
        end

        def date_to=(val)
          attributes[:dateTo] = val
        end

        def state
          attributes[:state]
        end

        def state=(val)
          attributes[:state] = val
        end

        def subject_name
          attributes[:subjectName]
        end

        def subject_name=(val)
          attributes[:subjectName] = val
        end

        def subject_code
          attributes[:subjectCode]
        end

        def subject_code=(val)
          attributes[:subjectCode] = val
        end

        def casted_subject_name
          attributes[:castedSubjectName]
        end

        def casted_subject_name=(val)
          attributes[:castedSubjectName] = val
        end

        def casted_subject_code
          attributes[:castedSubjectCode]
        end

        def casted_subject_code=(val)
          attributes[:castedSubjectCode] = val
        end

        def cast_direction
          attributes[:castDirection]
        end

        def cast_direction=(val)
          attributes[:castDirection] = val
        end

        def casted_subject_entity_type_uri
          attributes[:castedSubjectEntityTypeUri]
        end

        def casted_subject_entity_type_uri=(val)
          if val
            attributes[:castedSubjectEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectEntityTypeUri] = nil
          end
        end

        def subject_entity_type_uri
          attributes[:subjectEntityTypeUri]
        end

        def subject_entity_type_uri=(val)
          if val
            attributes[:subjectEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:subjectEntityTypeUri] = nil
          end
        end

        def visible
          attributes[:visible]
        end

        def visible=(val)
          attributes[:visible] = val
        end

      end
    end

  end

end
