require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Sheet
      class SheetAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the sheet.
        attr_accessor :uri

        # Name of the sheet.
        attr_accessor :name

        # Code of the sheet.
        attr_accessor :code

        # UESURI of the sheet template.
        attr_accessor :template_uri

        # Order of sheet on artifact.
        attr_accessor :order

        # Flag of main sheet.
        attr_accessor :main

        # Description of the sheet.
        attr_accessor :description

        # Version of the sheet.
        attr_accessor :version_label

        # Specifies if the sheet is locked.
        attr_accessor :locked

        # When the sheet has been locked. Null if it is unlocked.
        attr_accessor :lock_time

        # What role has locked the sheet. Null if it is unlocked.
        attr_accessor :lock_role_uri

        # Who (which access role) has locked the sheet. Null if it is unlocked.
        attr_accessor :lock_access_role_uri

        # Flag of visible sheet.
        attr_accessor :visible

        # Flag of width sheet.
        attr_accessor :width

        # Create time of the sheet
        attr_accessor :create_time

        # Update time of the sheet
        attr_accessor :update_time
        
        # Version of the sheet
        attr_accessor :version
        
        # UESURI of the entity type of the sheet (see @{cz.ues.platform.sysc.entitytype.UESEntityType} for more info).
        attr_accessor :entity_type_uri
        
        # Flag indicating if sheet can be edited in visual.
        attr_accessor :enabled_editing
        
        def uri 
          attributes[:uri]
        end

        def uri=(val) 
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def template_uri 
          attributes[:templateUri]
        end

        def template_uri=(val) 
          if val
            attributes[:templateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:templateUri] = nil
          end
        end

        def order 
          attributes[:order]
        end

        def order=(val) 
          attributes[:order] = val
        end

        def main 
          attributes[:main]
        end

        def main=(val) 
          attributes[:main] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end

        def version_label 
          attributes[:versionLabel]
        end

        def version_label=(val) 
          attributes[:versionLabel] = val
        end

        def locked 
          attributes[:locked]
        end

        def locked=(val) 
          attributes[:locked] = val
        end

        def lock_time 
          attributes[:lockTime]
        end

        def lock_time=(val) 
          attributes[:lockTime] = val
        end

        def lock_role_uri 
          attributes[:lockRoleUri]
        end

        def lock_role_uri=(val) 
          if val
            attributes[:lockRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:lockRoleUri] = nil
          end
        end

        def lock_access_role_uri 
          attributes[:lockAccessRoleUri]
        end

        def lock_access_role_uri=(val) 
          if val
            attributes[:lockAccessRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:lockAccessRoleUri] = nil
          end
        end

        def visible 
          attributes[:visible]
        end

        def visible=(val) 
          attributes[:visible] = val
        end

        def width 
          attributes[:width]
        end

        def width=(val) 
          attributes[:width] = val
        end

        def create_time 
          attributes[:createTime]
        end

        def create_time=(val) 
          attributes[:createTime] = val
        end

        def update_time 
          attributes[:updateTime]
        end

        def update_time=(val) 
          attributes[:updateTime] = val
        end
        
        # @deprecated Use {SheetAttributes#version} instead.
        def revision 
          attributes[:version]
        end
        
        # @deprecated Use {SheetAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end
        
        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end
        
        def entity_type_uri 
          attributes[:entityTypeUri]
        end
   
        def entity_type_uri=(val) 
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end
        
        def enabled_editing 
          attributes[:enabledEditing]
        end

        def enabled_editing=(val) 
          attributes[:enabledEditing] = val
        end       

      end
    end

  end
end
