require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Application Deployment Kit.
  module OS
    # Module Widget.
    module Widget
      # @see Widget#get_attributes
      class WidgetAttributes < UU::OS::REST::DTO

        # The code of the widget. Never nil.
        attr_accessor :code

        # UESURI of the company where the widget is located.
        # @deprecated
        attr_accessor :company_uri

        # UESURI of the competent for widget.
        attr_accessor :competent_role_uri

        # The creation stamp of the widget. Never nil.
        attr_accessor :creation_stamp

        # The creation time of the widget. Never nil.
        attr_accessor :creation_time

        # The description of the widget. Never nil.
        attr_accessor :description

        # UESURI of the entity type of the widget (@see cz.ues.platform.sysc.entitytype.UESEntityType for more info). Never nil.
        attr_accessor :entity_type_uri

        # UESURI of the widget's icon. When nil is set, the widget uses icon from meta artifact.
        attr_accessor :icon_uri

        # UESURI of the widget's container.
        attr_accessor :location_uri

        # UESURI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # The modification time of the widget. Never nil.
        attr_accessor :modification_stamp

        # The modification stamp of the widget. Never nil.
        attr_accessor :modification_time

        # The name of the widget. Never nil.
        attr_accessor :name

        # The normalized UESURI of the widget. Never nil.
        attr_accessor :uri

        # UESURI of the organizational unit in which the widget lies.
        attr_accessor :organizational_unit_uri

        # Security level of the widget. Never nil.
        attr_accessor :security_level

        # Version of the widget. Never nil.
        attr_accessor :version

        # Path at which the widget's controller is deployed.
        attr_accessor :controller_url_path

        # Describes whether the widget will by inserted into the HTML directly or in the iframe.
        attr_accessor :trusted

        # Describes whether the widget will be in the list of available widgets in editor. Never nil.
        attr_accessor :editor_available

        # Placeholder image of the widget in editor.
        attr_accessor :placeholder_image

        # Default width of the widget in content.
        attr_accessor :width

        # Default height of the widget in content.
        attr_accessor :height

        # Width of the widget placeholder in editor. It is defined for widgets for which it is not possible to set width and height.
        attr_accessor :placeholder_width

        # Height of the widget placeholder in editor. It is defined for widgets for which it is not possible to set width and height.
        attr_accessor :placeholder_height
        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          if val.kind_of?String
            attributes[:creationTime] = Time.parse(val)
          else
            attributes[:creationTime] = val
          end
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          if val.kind_of?String
            attributes[:modificationTime] = Time.parse(val)
          else
            attributes[:modificationTime] = val
          end
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def controller_url_path
          attributes[:controllerUrlPath]
        end

        def controller_url_path=(val)
          attributes[:controllerUrlPath] = val
        end

        def trusted
          attributes[:trusted]
        end

        def trusted=(val)
          attributes[:trusted] = val
        end

        def editor_available
          attributes[:editorAvailable]
        end

        def editor_available=(val)
          attributes[:editorAvailable] = val
        end

        def placeholder_image
          attributes[:placeholderImage]
        end

        def placeholder_image=(val)
          attributes[:placeholderImage] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def height
          attributes[:height]
        end

        def height=(val)
          attributes[:height] = val
        end

        def placeholder_width
          attributes[:placeholderWidth]
        end

        def placeholder_width=(val)
          attributes[:placeholderWidth] = val
        end

        def placeholder_height
          attributes[:placeholderHeight]
        end

        def placeholder_height=(val)
          attributes[:placeholderHeight] = val
        end

      end
    end
  end

end
